@@ -397,6 +397,8 @@ setMethod("get.most.probable.values",
             num.nodes <- num.nodes(bn)
             variables <- variables(bn)
             node.sizes <- node.sizes(bn)
+            discrete   <- discreteness(bn)
+            quantiles  <- quantiles(bn)
 
             mpv  <- array(rep(0,num.nodes), dim=c(num.nodes), dimnames=list(variables))
 
@@ -417,10 +419,12 @@ setMethod("get.most.probable.values",
             
             for (node in sorted.nodes)
             {
+              pot  <- cpts[[node]]
+              vars <- c(unlist(dim.vars[[node]]))
               if (length(prev.values) == 0 || is.na(prev.values[node]))
               {
-                pot  <- cpts[[node]]
-                vars <- c(unlist(dim.vars[[node]]))
+                #pot  <- cpts[[node]]
+                #vars <- c(unlist(dim.vars[[node]]))
 
                 # sum out parent variables
                 if (length(dim.vars[[node]]) > 1)
@@ -463,6 +467,18 @@ setMethod("get.most.probable.values",
                 }
               }
             }
+
+            # sample continuous values, if possible
+            if (length(quantiles) > 0) {
+              for (node in sorted.nodes) {
+                if (discrete[node] == FALSE && length(quantiles[[node]]) > 1) {
+                  lb <- quantiles[[node]][mpv[node]]
+                  ub <- quantiles[[node]][mpv[node]+1]
+                  mpv[node] <- runif(1, lb, ub)
+                }
+              }
+            }
+
             return(mpv)
           })
 
